herosdevices.hardware.rohde_schwarz.ngx - Heros Devices 0.11.1 documentation

Skip to content
Back to top
View this page

# herosdevices.hardware.rohde_schwarz.ngx

Device driver for Rohde Schwarz NGX Power Supplies.

## Module Contents

class herosdevices.hardware.rohde_schwarz.ngx.NGX(resource: str, channels: tuple[tuple[int, str], Ellipsis] = ((1, 'ch1'),), keep_alive: bool = True, **kwargs)

  Bases: `herosdevices.core.templates.VisaDeviceTemplate`

  Driver for Rohde Schwarz NGX Power Supplies using the VISA interface.

  The desired channels have to configured using the channel index (starting from 1) and a user-friendly channel name. For each channel, the HERO gains properties channel_name_ current, voltage, power and status. In addition, current and voltage can be set using the property.

  Querying can also occur for the configured number of channels simultaneously by using the class-level properties.

  All properties are provided as observable data.

  Parameters:

    - resource – VISA resource identifier e.g. TCPIP::my_device_address::INSTR.

    - channels – List of tuples of channel index and channel name.

    - keep_alive – Keep VISA connection open.

  channels: tuple[tuple[int, str], Ellipsis] = ((1, 'ch1'),)
  resource
  connection